package com.ruoyi.learn.service;

import java.util.List;
import com.ruoyi.learn.domain.LearnPaper;

/**
 * 试卷Service接口
 *
 * @author ruoyi
 * @date 2025-09-18
 */
public interface ILearnPaperService
{
    /**
     * 查询试卷
     *
     * @param id 试卷主键
     * @return 试卷
     */
    public LearnPaper selectLearnPaperById(Long id);

    /**
     * 查询试卷列表
     *
     * @param learnPaper 试卷
     * @return 试卷集合
     */
    public List<LearnPaper> selectLearnPaperList(LearnPaper learnPaper);
    public List<LearnPaper> selectLearnPaperForExam(LearnPaper learnPaper);
    public List<LearnPaper> selectPapersListFromFavorites(LearnPaper papers);
    /**
     * 新增试卷
     *
     * @param learnPaper 试卷
     * @return 结果
     */
    public int insertLearnPaper(LearnPaper learnPaper);

    /**
     * 修改试卷
     *
     * @param learnPaper 试卷
     * @return 结果
     */
    public int updateLearnPaper(LearnPaper learnPaper);

    /**
     * 批量删除试卷
     *
     * @param ids 需要删除的试卷主键集合
     * @return 结果
     */
    public int deleteLearnPaperByIds(Long[] ids);

    /**
     * 删除试卷信息
     *
     * @param id 试卷主键
     * @return 结果
     */
    public int deleteLearnPaperById(Long id);
}
